@@ -1,7 +1,7 @@
 ;; -*- mode: scheme; coding: utf-8 -*-
 
 ;;;;
-;;;; Copyright (C) 2016 - 2018
+;;;; Copyright (C) 2016 - 2019
 ;;;; Free Software Foundation, Inc.
 
 ;;;; This file is part of GNU Guile-CV.
@@ -942,7 +942,7 @@ Target.B = ((1 - Source.A) * BGColor.B) + (Source.A * Source.B)
 			 (im-transpose-channel channel width height))
 	       idata))))))
 
-(define (im-transpose-channel channel width height)
+#;(define (im-transpose-channel channel width height)
   (let ((t-width height)
         (to (im-make-channel height width)))
     (do ((i 0
@@ -955,6 +955,11 @@ Target.B = ((1 - Source.A) * BGColor.B) + (Source.A * Source.B)
                               (im-fast-channel-ref channel i j width))))
     to))
 
+(define (im-transpose-channel channel width height)
+  (let ((to (im-make-channel height width)))
+    (f32vector-transpose channel width height to)
+    to))
+
 (define (im-invert image)
   (match image
     ((width height n-chan idata)
